@@ -12,7 +12,7 @@ export async function activate(context: vscode.ExtensionContext) {
   log("Activating...");
 
   try {
-    let call_flowistry = await setup();
+    let call_flowistry = await setup(context);
     if (call_flowistry === null) {
       return;
     }
@@ -31,7 +31,7 @@ export async function activate(context: vscode.ExtensionContext) {
     });
 
     register_with_opts("effects", () => effects(context, call_flowistry!));
-  } catch (e) {
+  } catch (e: any) {
     show_error(e.toString());
   }
 
